@@ -88,15 +88,6 @@ $form->{login} = 'test';
 # $locale->text('Nov')
 # $locale->text('Dec')
 
-sub pos_adjust {
-    $form->{rowcount} = 3;
-    eval {require "pos.conf.pl"} || $form->error($locale->text(
-      "Could not open pos.conf.pl in [_1] line [_2]: [_3]", 
-       __FILE__, __LINE__, $!));
-    $form->{accno_1} = $pos_config{'close_cash_accno'};
-    $form->{accno_2} = $pos_config{'coa_prefix'};
-    $form->{accno_3} = $pos_config{'coa_prefix'};
-}
 
 sub edit_and_save {
     use LedgerSMB::DBObject::Draft;
@@ -121,7 +112,7 @@ sub approve {
     if ($form->{callback}){
         print "Location: $form->{callback}\n";
         print "Status: 302 Found\n\n";
-        print qq|<html><body class="$form->{dojo_theme}">|;
+        print qq|<html><body class="lsmb $form->{dojo_theme}">|;
         my $url = $form->{callback};
         print qq|If you are not redirected automatically, click <a href="$url">|
                 . qq|here</a>.</body></html>|;
@@ -131,17 +122,6 @@ sub approve {
     }
 }
 
-sub add_pos_adjust {
-    $form->{pos_adjust} = 1;
-    $form->{reference} =
-      $locale->text("Adjusting Till: (till) Source: (source)");
-    $form->{description} =
-      $locale->text("Adjusting till due to data entry error.");
-    $form->{callback} =
-"$form->{script}?action=add_pos_adjust&transfer=$form->{transfer}&path=$form->{path}&login=$form->{login}&sessionid=$form->{sessionid}"
-      unless $form->{callback};
-    &add;
-}
 
 sub new {
      for my $row (0 .. $form->{rowcount}){
@@ -173,12 +153,9 @@ sub add {
     if (!$form->{rowcount}){
         $form->{rowcount} = ( $form->{transfer} ) ? 3 : 9;
     }
-    if ( $form->{pos_adjust} ) {
-        &pos_adjust;
-    }
     $form->{oldtransdate} = $form->{transdate};
     $form->{focus}        = "reference";
-    display_form(1);	
+    display_form(1);
 
 }
 
@@ -188,12 +165,15 @@ sub display_form
     $form->{separate_duties}
         = $LedgerSMB::Company_Config::settings->{separate_duties};
     #Add General Ledger Transaction
-    $form->all_business_units($form->{transdate}, undef, 'GL');
+
+    # filter out '' transdates
+    my $transdate = ($form->{transdate}) ? $from->{transdate} : undef;
+    $form->all_business_units($transdate, undef, 'GL');
     @{$form->{sequences}} = LedgerSMB::Setting::Sequence->list('glnumber')
          unless $form->{id};
     $form->close_form;
-    $form->open_form; 
-    my ($init) = @_; 
+    $form->open_form;
+    my ($init) = @_;
     # Form header part begins -------------------------------------------
     if (@{$form->{all_department}}){
         unshift @{ $form->{all_department} }, {};
@@ -223,7 +203,7 @@ sub display_form
 
     if ( ( $rows = $form->numtextrows( $form->{notes}, 50 ) ) > 1 ) {
         $form->{rowsnotes}=$rows;$form->{colsnotes}=50;
-	$form->{colrownotes}=1;
+    $form->{colrownotes}=1;
     }
     else {
                $form->{colrownotes}=0;
@@ -235,12 +215,11 @@ sub display_form
 
     $focus = ( $form->{focus} ) ? $form->{focus} : "debit_$form->{rowcount}";
     our %hiddens = (
-    'action' => $form->{action},
     'direction' => $form->{direction},
     'oldsort' => $form->{oldsort},
     'path' => $form->{path},
     'login' => $form->{login},
-    'sessionid' => $form->{sessionid},
+    'session_id' => $form->{session_id},
     'batch_id' => $form->{batch_id},
     'id' => $form->{id},
     'transfer' => $form->{transfer},
@@ -249,106 +228,103 @@ sub display_form
     'oldtransdate' => $form->{oldtransdate},
     'recurring' => $form->{recurring},
     'title' => $title,
-    'approved' => $form->{approved}
+    'approved' => $form->{approved},
+     'callback' => $form->{callback},
+     'form_id' => $form->{form_id},
     );
-        
-   
+
+
     #Disply_Row Part  Begins-------------------------------------
 
     our @displayrows;
     &display_row($init);
-   
+
     #Form footer  Begins------------------------------------------
 
   for (qw(totaldebit totalcredit)) {
       $form->{$_} =
-	$form->format_amount( \%myconfig, $form->{$_}, 2, "0" );
+    $form->format_amount( \%myconfig, $form->{$_}, 2, "0" );
   }
 
-  $hiddens{sessionid}=$form->{sessionid};
-  $hiddens{callback}=$form->{callback};
-  $hiddens{form_id}= $form->{form_id};
   $transdate = $form->datetonum( \%myconfig, $form->{transdate} );
   $closedto  = $form->datetonum( \%myconfig, $form->{closedto} );
   my @buttons;
   if ( !$form->{readonly} ) {
-	      my $i=1;
-	      %button = (
-		  'update' =>
-		    { ndx => 1, key => 'U', value => $locale->text('Update') },
-		  'post' => { ndx => 3, key => 'O', value => $locale->text('Post') },
-                  'edit_and_save' => {ndx => 4, key => 'V', 
+          my $i=1;
+          %button = (
+          'update' =>
+            { ndx => 1, key => 'U', value => $locale->text('Update') },
+          'post' => { ndx => 3, key => 'O', value => $locale->text('Post') },
+                  'edit_and_save' => {ndx => 4, key => 'V',
                           value => $locale->text('Save Draft') },
                   'save_temp' =>
-                    { ndx   => 9, 
-                      key   => 'T', 
+                    { ndx   => 9,
+                      key   => 'T',
                       value => $locale->text('Save Template') },
-		  'save_as_new' =>
-		    { ndx => 6, key => 'N', value => $locale->text('Save as new') },
-		  'schedule' =>
-		    { ndx => 7, key => 'H', value => $locale->text('Schedule') },
-                  'new' => 
-                    { ndx => 9, key => 'N', value => $locale->text('New') },
-                   'copy_to_new' =>
-                    { ndx => 10, key => 'C', value => $locale->text('Copy to New') },
-	      );
+          'save_as_new' =>
+            { ndx => 6, key => 'N', value => $locale->text('Save as new') },
+          'schedule' =>
+            { ndx => 7, key => 'H', value => $locale->text('Schedule') },
+          'new' =>
+            { ndx => 9, key => 'N', value => $locale->text('New') },
+          'copy_to_new' =>
+            { ndx => 10, key => 'C', value => $locale->text('Copy to New') },
+         );
 
-	      if ($form->{separate_duties}){            
-		  $hiddens{separate_duties}=$form->{separate_duties};
-		  $button{post}->{value} = $locale->text('Save'); 
-	      }
-	      %a = ();
+          if ($form->{separate_duties}){
+          $hiddens{separate_duties}=$form->{separate_duties};
+          $button{post}->{value} = $locale->text('Save');
+          }
+          %a = ();
               $a{'save_temp'} = 1;
 
-	      if ( $form->{id}) {
-                  $a{'new'} = 1;
+          if ( $form->{id}) {
+              $a{'new'} = 1;
 
-		  for ( 'save_as_new', 'schedule', 'copy_to_new' ) { $a{$_} = 1 }
+              for ( 'save_as_new', 'schedule', 'copy to new' ) { $a{$_} = 1 }
 
-		  for ( 'post', 'delete' ) { $a{$_} = 1 }
-	      }
-	      else {
-                 $a{'update'} = 1;
-		  if ( ($transdate > $closedto) or !$closedto ) {
-		      for ( "post", "schedule" ) { $a{$_} = 1 }
-		  }
-	      }
+              for ( 'post', 'delete' ) { $a{$_} = 1 }
+          } else {
+              $a{'update'} = 1;
+              if ( ! $closedto or ($transdate > $closedto ) ) {
+                  for ( "post", "schedule" ) { $a{$_} = 1 }
+              }
+          }
+          if ($form->{id} && (!$form->{approved} && !$form->{batch_id})){
+        $button{approve} = {
+            ndx   => 3,
+            key   => 'S',
+            value => $locale->text('Post') };
+        $a{approve} = 1;
+        $a{edit_and_save} = 1;
+        $a{update} = 1;
+        if ($form->is_allowed_role(['draft_modify'])) {
+            $button{edit_and_save} = {
+            ndx   => 4,
+            key   => 'O',
+            value => $locale->text('Save Draft') };
+        }
+        delete $button{post};
+          }
+          if ($form->{id} && ($form->{approved} || $form->{batch_id})) {
+          delete $button{post};
+          }
 
-	      if ($form->{id} && (!$form->{approved} && !$form->{batch_id})){
-		$button{approve} = { 
-			ndx   => 3, 
-			key   => 'S', 
-			value => $locale->text('Post') };
-		$a{approve} = 1;
-		$a{edit_and_save} = 1;
-		$a{update} = 1;
-		if (grep /__draft_modify$/, @{$form->{_roles}}){
-		    $button{edit_and_save} = { 
-			ndx   => 4, 
-			key   => 'O', 
-			value => $locale->text('Save Draft') };
-		}
-		delete $button{post};
-	      }
-	      if ($form->{id} && ($form->{approved} || $form->{batch_id})) {
-		  delete $button{post};
-	      }
-
-	      for ( keys %button ) { delete $button{$_} if !$a{$_} }      
-	      my $i=1;
-	      for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button )
-	      {
-				  push @buttons, {
-				  name => 'action',
-				  value => $_ ,
-				  text => $button{$_}->{value},
-				  type => 'submit',
-				  class => 'submit',
-				  accesskey => $button{$_}->{key},
-				  order => $i
-						};
-				  $i++;
-	      }
+          for ( keys %button ) { delete $button{$_} if !$a{$_} }
+          my $i=1;
+          for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button )
+          {
+                  push @buttons, {
+                  name => 'action',
+                  value => $_ ,
+                  text => $button{$_}->{value},
+                  type => 'submit',
+                  class => 'submit',
+                  accesskey => $button{$_}->{key},
+                  order => $i
+                        };
+                  $i++;
+          }
 
   }
 
@@ -358,27 +334,22 @@ sub display_form
   }
   my $template;
   my $template = LedgerSMB::Template->new(
-			    user => \%myconfig,
-			    locale => $locale,
-			    path => 'UI/journal',
-			    template => 'journal_entry',
-			    format => 'HTML',
-					);
+                user => \%myconfig,
+                locale => $locale,
+                path => 'UI/journal',
+                template => 'journal_entry',
+                format => 'HTML',
+                    );
 
   $template->render({
-			form => \%$form,
-			buttons => \@buttons,
-			hiddens => \%hiddens,
-			displayrows => \@displayrows        
+            form => \%$form,
+            buttons => \@buttons,
+            hiddens => \%hiddens,
+            displayrows => \@displayrows
                    });
 
-  if ( $form->{lynx} ) {
-      require "bin/menu.pl";
-      &menubar;
-  }
-
 }
- 
+
 
 sub save_temp {
     use LedgerSMB;
@@ -393,19 +364,19 @@ sub save_temp {
     $lsmb->{type} = 'gl';
     $lsmb->{journal_lines} = [];
     for my $iter (0 .. $form->{rowcount}){
-        if ($form->{"accno_$iter"} and 
+        if ($form->{"accno_$iter"} and
                   (($form->{"credit_$iter"} != 0) or ($form->{"debit_$iter"} != 0))){
              my ($acc_id, $acc_name) = split /--/, $form->{"accno_$iter"};
-             my $amount = $form->{"credit_$iter"} || ( $form->{"debit_$iter"} 
+             my $amount = $form->{"credit_$iter"} || ( $form->{"debit_$iter"}
                                                      * -1 );
-             push @{$lsmb->{journal_lines}}, 
+             push @{$lsmb->{journal_lines}},
                   {accno => $acc_id,
-                   amount => $amount, 
+                   amount => $amount,
                    cleared => false,
                   };
         }
     }
-    $template = LedgerSMB::DBObject::TransTemplate->new(base => $lsmb);
+    $template = LedgerSMB::DBObject::TransTemplate->new({base => $lsmb});
     $template->save;
     $form->redirect( $locale->text('Template Saved!') );
 }
@@ -413,88 +384,86 @@ sub save_temp {
 
 sub display_row
 {
- 
-  my ($init) = @_;  
+
+  my ($init) = @_;
   $form->{totaldebit}  = 0;
   $form->{totalcredit} = 0;
 
-  for $i ( 0 .. $form->{rowcount} ) 
+  for $i ( 0 .. $form->{rowcount} )
   {
 
         my $temphash1;
         $temphash1->{index}=$i;
         $temphash1->{source}=$form->{"source_$i"};#input box
-	$temphash1->{memo}=$form->{"memo_$i"}; #input box;
-	$temphash1->{accnoset}=1;
+    $temphash1->{memo}=$form->{"memo_$i"}; #input box;
+    $temphash1->{accnoset}=1;
         $temphash1->{projectset}=1;
         $temphash1->{fx_transactionset}=1;
-	if (!defined $form->{"accno_$i"})
-	{
-			      $temphash1->{accnoset}=0;   #use  @{ $form->{all_accno} }
-			      $temphash1->{projectset}=0; #use  @{ $form->{all_project} }
-			      $temphash1->{fx_transactionset}=0;    #use checkbox and value=1 if transfer=1
-			      
+    if (!defined $form->{"accno_$i"} || ! $form->{"accno_$i"})
+    {
+                  $temphash1->{accnoset}=0;   #use  @{ $form->{all_accno} }
+                  $temphash1->{projectset}=0; #use  @{ $form->{all_project} }
+                  $temphash1->{fx_transactionset}=0;    #use checkbox and value=1 if transfer=1
+
         }
         else
-	{
+    {
                               $form->{"debit_$i"} = LedgerSMB::PGNumber->from_input($form->{"debit_$i"});
-                              $form->{"credit_$i"}= LedgerSMB::PGNumber->from_input($form->{"credit_$i"}); 	    
-			      $form->{totaldebit}  += $form->{"debit_$i"};
-			      $form->{totalcredit} += $form->{"credit_$i"};			      
-			      for (qw(debit credit)) {
-				  $form->{"${_}_$i"} =
-				    ( $form->{"${_}_$i"} )
-				    ? $form->format_amount( \%myconfig, $form->{"${_}_$i"}, 2 )
-				    : "";
-			      }
+                              $form->{"credit_$i"}= LedgerSMB::PGNumber->from_input($form->{"credit_$i"});
+                  $form->{totaldebit}  += $form->{"debit_$i"};
+                  $form->{totalcredit} += $form->{"credit_$i"};
+                  for (qw(debit credit)) {
+                  $form->{"${_}_$i"} =
+                    ( $form->{"${_}_$i"} )
+                    ? $form->format_amount( \%myconfig, $form->{"${_}_$i"}, 2 )
+                    : "";
+                  }
 
-			      $temphash1->{debit}=$form->{"debit_$i"};
-			      $temphash1->{credit}=$form->{"credit_$i"};
+                  $temphash1->{debit}=$form->{"debit_$i"};
+                  $temphash1->{credit}=$form->{"credit_$i"};
                               for my $cls(@{$form->{bu_class}}){
                                   $temphash1->{"b_unit_$cls->{id}"} =
                                          $form->{"b_unit_$cls->{id}_$i"};
-                              } 
+                              }
 
-			      if ( $i < $form->{rowcount} )
-			      {					      
-						    $temphash1->{accno}=$form->{"accno_$i"};
+                  if ( $i < $form->{rowcount} )
+                  {
+                            $temphash1->{accno}=$form->{"accno_$i"};
 
-						    if ( $form->{projectset} and $form->{"projectnumber_$i"} ) {
-							$temphash1->{projectnumber}=$form->{"projectnumber_$i"}; 
-							$temphash1->{projectnumber}=~ s/--.*//;
-								
-						    }
-						    
-						    if ( $form->{transfer} and $form->{"fx_transaction_$i"})
-						    {
-							$temphash1->{fx_transactionset}=1; 
-						    }
-						    else 
-						    {
-							
-							$temphash1->{fx_transactionset}=0;
-						    }
-						    $hiddens{"accno_$i"}=$form->{"accno_$i"};
-						    $hiddens{"projectnumber_$i"}=$form->{"projectnumber_$i"};
-						
-			      }
-			      else 
-			      {
-						    $temphash1->{accnoset}=0;   #use  @{ $form->{all_accno} }
-						    $temphash1->{projectset}=0;   #use  @{ $form->{all_accno} }
-						    $temphash1->{fx_transactionset}=0;
-						    
-			      }
+                            if ( $form->{projectset} and $form->{"projectnumber_$i"} ) {
+                            $temphash1->{projectnumber}=$form->{"projectnumber_$i"};
+                            $temphash1->{projectnumber}=~ s/--.*//;
+
+                            }
+
+                            if ( $form->{transfer} and $form->{"fx_transaction_$i"})
+                            {
+                            $temphash1->{fx_transactionset}=1;
+                            }
+                            else
+                            {
+
+                            $temphash1->{fx_transactionset}=0;
+                            }
+                            $hiddens{"accno_$i"}=$form->{"accno_$i"};
+                            $hiddens{"projectnumber_$i"}=$form->{"projectnumber_$i"};
+
+                  }
+                  else
+                  {
+                            $temphash1->{accnoset}=0;   #use  @{ $form->{all_accno} }
+                            $temphash1->{projectset}=0;   #use  @{ $form->{all_accno} }
+                            $temphash1->{fx_transactionset}=0;
+
+                  }
 
          }
- 
+
          push @displayrows,$temphash1;
 
- } 
+ }
 
 $hiddens{rowcount}=$form->{rowcount};
-$hiddens{pos_adjust}=$form->{pos_adjust};
-
 }
 
 sub edit {
@@ -520,8 +489,8 @@ sub edit {
     }
     $i = 0;
 
-    my $minusOne    = new Math::BigFloat(-1);#HV make sure BigFloat stays BigFloat
-    my $plusOne     = new Math::BigFloat(1);#HV make sure BigFloat stays BigFloat
+    my $minusOne    = new LedgerSMB::PGNumber(-1);#HV make sure BigFloat stays BigFloat
+    my $plusOne     = new LedgerSMB::PGNumber(1);#HV make sure BigFloat stays BigFloat
 
     foreach $ref ( @{ $form->{GL} } ) {
         $form->{"accno_$i"} = "$ref->{accno}--$ref->{description}";
@@ -610,7 +579,7 @@ sub update {
      $form->{transdate} = LedgerSMB::PGDate->from_input($form->{transdate})->to_output();
      if ( $form->{transdate} ne $form->{oldtransdate} ) {
          $form->{oldtransdate} = $form->{transdate};
-     } 
+     }
 
     $form->all_business_units($form->{transdate}, undef, 'GL');
     GL->get_all_acc_dep_pro( \%myconfig, \%$form );
@@ -625,8 +594,8 @@ sub update {
     }
 
     for $i ( 0 .. $form->{rowcount} ) {
-        $form->{"debit_$i"} =~ s/\s+//g; 
-        $form->{"credit_$i"} =~ s/\s+//g; 
+        $form->{"debit_$i"} =~ s/\s+//g;
+        $form->{"credit_$i"} =~ s/\s+//g;
         unless ( ( $form->{"debit_$i"} eq "" )
             && ( $form->{"credit_$i"} eq "" ) )
         {
@@ -655,7 +624,7 @@ sub update {
             $count++;
         }
     }
-    
+
     for $i ( 1 .. $count ) {
         $j = $i - 1;
         for (@flds) { $form->{"${_}_$j"} = $a[$j]->{$_} }
@@ -666,9 +635,9 @@ sub update {
     }
 
     $form->{rowcount} = $count + $min_lines;
- 
-    
-    
+
+
+
     &display_form;
 }
 
@@ -706,7 +675,7 @@ sub post {
 }
 
 sub delete {
-    $form->error($locale->text('Cannot delete posted transaction')) 
+    $form->error($locale->text('Cannot delete posted transaction'))
        if ($form->{approved});
     my $lsmb = LedgerSMB->new();
     $lsmb->merge($form);
@@ -722,8 +691,8 @@ sub check_balanced {
     my ($form) = @_;
     # add up debits and credits
     for $i ( 0 .. $form->{rowcount} ) {
-        $form->{"debit_$i"} =~ s/\s+//g; 
-        $form->{"credit_$i"} =~ s/\s+//g; 
+        $form->{"debit_$i"} =~ s/\s+//g;
+        $form->{"credit_$i"} =~ s/\s+//g;
         $dr = $form->parse_amount( \%myconfig, $form->{"debit_$i"} );
         $cr = $form->parse_amount( \%myconfig, $form->{"credit_$i"} );
 
